// -*- C++ -*-
//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.inf.usi.ch/carzaniga/siena/
//
//  Authors: Antonio Carzaniga
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 2002 University of Colorado
//
//  Siena is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//  
//  Siena is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with Siena.  If not, see <http://www.gnu.org/licenses/>.
//
#ifndef SIENA_ATABLE_H
#define SIENA_ATABLE_H

#include <cassert>
#include <siena/allocator.h>

namespace siena {

class Attribute;

class ATableNode;
/** @brief an attribute table in which attribute descriptors are
 *  accessed by name.
 *
 *  This table implements a map between attribute names and pointers
 *  to attribute descriptors.
 **/
class ATable {
public:
			ATable() { clear(); };

    Attribute **	insert(const char *, const char *, FTAllocator &);
    const Attribute *	find(const char *, const char *) const;

    void		clear();

    static const int	EndChar = -1;

    void		consolidate();

private:
    ATableNode *	roots[256];
};

} // end namespace siena

#endif
